@@ -1,14 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "contactprintthemeeditorutil.h"
 
-ContactPrintThemeEditorutil::ContactPrintThemeEditorutil()
-{
-}
+ContactPrintThemeEditorutil::ContactPrintThemeEditorutil() = default;
 
 QString ContactPrintThemeEditorutil::defaultContact() const
 {
