@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,7 +7,7 @@
 #include "contactprintthemepreview.h"
 #include "contactprintthemeeditor_debug.h"
 #include "contactprintthemeeditorutil.h"
-#include <Akonadi/Contact/GrantleePrint>
+#include <Akonadi/GrantleePrint>
 #include <KConfigGroup>
 #include <KContacts/VCardConverter>
 #include <KSharedConfig>
@@ -18,7 +18,7 @@ ContactPrintThemePreview::ContactPrintThemePreview(const QString &projectDirecto
     : GrantleeThemeEditor::PreviewWidget(parent)
     , mThemePath(projectDirectory)
 {
-    QHBoxLayout *hbox = new QHBoxLayout(this);
+    auto hbox = new QHBoxLayout(this);
     hbox->setContentsMargins(0, 0, 0, 0);
     mViewer = new QWebEngineView(this);
     mViewer->setContextMenuPolicy(Qt::NoContextMenu);
@@ -26,9 +26,7 @@ ContactPrintThemePreview::ContactPrintThemePreview(const QString &projectDirecto
     loadConfig();
 }
 
-ContactPrintThemePreview::~ContactPrintThemePreview()
-{
-}
+ContactPrintThemePreview::~ContactPrintThemePreview() = default;
 
 void ContactPrintThemePreview::updateViewer()
 {
