@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,9 +15,11 @@
 #include <QIcon>
 int main(int argc, char **argv)
 {
-    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
+    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+#endif
     QApplication app(argc, argv);
-    app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
     app.setDesktopFileName(QStringLiteral("org.kde.contactprintthemeeditor"));
     KLocalizedString::setApplicationDomain("contactprintthemeeditor");
     KAboutData aboutData(QStringLiteral("contactprintthemeeditor"),
@@ -25,10 +27,9 @@ int main(int argc, char **argv)
                          QStringLiteral(GRANTLEEEDITOR_VERSION),
                          i18n("Contact Print Theme Editor"),
                          KAboutLicense::GPL_V2,
-                         i18n("Copyright © 2015-2021 contactprintthemeeditor authors"));
+                         i18n("Copyright © 2015-%1 contactprintthemeeditor authors", QStringLiteral("2022")));
     aboutData.addAuthor(i18n("Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("kaddressbook")));
-    aboutData.setOrganizationDomain(QByteArray("kde.org"));
     aboutData.setProductName(QByteArray("contactprintthemeeditor"));
 
     KAboutData::setApplicationData(aboutData);
@@ -42,7 +43,7 @@ int main(int argc, char **argv)
 
     KDBusService service;
 
-    ThemeEditorMainWindow *mw = new ThemeEditorMainWindow;
+    auto mw = new ThemeEditorMainWindow;
     mw->show();
     const int ret = app.exec();
     return ret;
