@@ -11,8 +11,6 @@
 #include "themeeditorwidget.h"
 #include "themesession.h"
 
-#include <kns3/uploaddialog.h>
-
 #include "headerthemeeditor_debug.h"
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -25,6 +23,7 @@
 #include <QFileDialog>
 #include <QHBoxLayout>
 #include <QPointer>
+#include <kwidgetsaddons_version.h>
 
 ThemeEditorPage::ThemeEditorPage(const QString &projectDir, const QString &themeName, QWidget *parent)
     : QWidget(parent)
@@ -156,12 +155,20 @@ void ThemeEditorPage::installTheme(const QString &themePath)
     QDir dir(themePath);
     QDir themeDir(themePath + QLatin1Char('/') + mDesktopPage->themeName());
     if (themeDir.exists()) {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        const int answer = KMessageBox::questionTwoActions(this,
+#else
         const int answer = KMessageBox::questionYesNo(this,
-                                                      i18n("Theme already exists. Do you want to overwrite it?"),
-                                                      i18n("Theme already exists"),
-                                                      KStandardGuiItem::overwrite(),
-                                                      KStandardGuiItem::cancel());
+#endif
+                                                           i18n("Theme already exists. Do you want to overwrite it?"),
+                                                           i18n("Theme already exists"),
+                                                           KStandardGuiItem::overwrite(),
+                                                           KStandardGuiItem::cancel());
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        if (answer == KMessageBox::ButtonCode::SecondaryAction) {
+#else
         if (answer == KMessageBox::No) {
+#endif
             return;
         }
     } else {
@@ -281,12 +288,20 @@ bool ThemeEditorPage::saveTheme(bool withConfirmation)
 {
     if (themeWasChanged()) {
         if (withConfirmation) {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            const int result = KMessageBox::questionTwoActionsCancel(this,
+#else
             const int result = KMessageBox::questionYesNoCancel(this,
-                                                                i18n("Do you want to save current project?"),
-                                                                i18n("Save current project"),
-                                                                KStandardGuiItem::save(),
-                                                                KStandardGuiItem::discard());
+#endif
+                                                                     i18n("Do you want to save current project?"),
+                                                                     i18n("Save current project"),
+                                                                     KStandardGuiItem::save(),
+                                                                     KStandardGuiItem::discard());
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            if (result == KMessageBox::ButtonCode::PrimaryAction) {
+#else
             if (result == KMessageBox::Yes) {
+#endif
                 storeTheme();
             } else if (result == KMessageBox::Cancel) {
                 return false;
