@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,9 +12,7 @@ ThemeEditorWidget::ThemeEditorWidget(QWidget *parent)
     createCompleterList();
 }
 
-ThemeEditorWidget::~ThemeEditorWidget()
-{
-}
+ThemeEditorWidget::~ThemeEditorWidget() = default;
 
 void ThemeEditorWidget::createCompleterList(const QStringList &extraCompletion)
 {
